#ifndef NT2_INCLUDE_FUNCTIONS_IDIVROUND_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IDIVROUND_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/idivround.hpp>

#endif
